==> jc-1.4.0.tar.gz: soot/tagkit/ConstantValueTag.c <==
// public abstract class soot.tagkit.ConstantValueTag

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 2441695b7a69eb12 java_lang_VMClass
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_VMClass
// @dep_header soot_tagkit_ConstantValueTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/VMClass.h"
#include "soot/tagkit/ConstantValueTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// protected byte[] bytes
static _jc_field _jc_soot_tagkit_ConstantValueTag$field_info$bytes = {
	.name=		"bytes",
	.signature=	"[B",
	.class=		&_jc_soot_tagkit_ConstantValueTag$type,
	.type=		&_jc_byte$array$prim$type,
	.access_flags=	_JC_ACC_PROTECTED,
	.offset=	_JC_OFFSETOF(_jc_soot_tagkit_ConstantValueTag$object, refs[-1].soot_tagkit_ConstantValueTag.bytes),
};

// Fields
static _jc_field *const _jc_soot_tagkit_ConstantValueTag$fields[] = {
	&_jc_soot_tagkit_ConstantValueTag$field_info$bytes
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_soot_tagkit_ConstantValueTag$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_tagkit_ConstantValueTag$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_tagkit_ConstantValueTag$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_tagkit_ConstantValueTag$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_ConstantValueTag$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_soot_tagkit_ConstantValueTag$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_ConstantValueTag$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_ConstantValueTag, _init$52f4ad9f2989aeee);

void
_jc_soot_tagkit_ConstantValueTag$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_tagkit_ConstantValueTag$object *this)
{
	struct _jc_soot_tagkit_ConstantValueTag$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(33);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getName()
//

static _jc_linenum _jc_soot_tagkit_ConstantValueTag$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_soot_tagkit_ConstantValueTag$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_ConstantValueTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_ConstantValueTag$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_ConstantValueTag$vtable, soot_tagkit_ConstantValueTag.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_soot_tagkit_ConstantValueTag$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_ConstantValueTag, getName$bec186f2ce7e1882);

_jc_java_lang_String$object *
_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_soot_tagkit_ConstantValueTag$object *this)
{
	jint i0;
	jint i1;
	jint i3;
	struct _jc_soot_tagkit_ConstantValueTag$object *r0;
	struct _jc_java_lang_Class$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(36);				// 0
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_Object, getClass$1f1ddb358c8ea7be, 0, r0);
	_JC_EXPLICIT_NULL_CHECK(env, r1);
	r2 = _JC_INVOKE_STATIC(env, java_lang_VMClass, getName$7a04fe8e1a654d36, 0, r1);
	_JC_EXPLICIT_NULL_CHECK(env, r2);
	i3 = _JC_PRIM_FIELD(env, r2, java_lang_String, count);
	i3 = i3 - 1;
	i3 = _JC_INVOKE_NONVIRTUAL(env, java_lang_String, lastIndexOf$f519cb8928895c80, 0, r2, 46, i3);
	_JC_LINE_NUMBER(37);				// 1
	i0 = i3 + 1;
	i1 = _JC_PRIM_FIELD(env, r2, java_lang_String, count);
	r3 = _JC_INVOKE_NONVIRTUAL(env, java_lang_String, substring$df0d95f5ebfea7dc, 0, r2, i0, i1);
	return r3;
}

//
// public byte[] getValue()
//

static _jc_linenum _jc_soot_tagkit_ConstantValueTag$linenum_table$getValue$824c7561d2f47329[];

static const unsigned char _jc_soot_tagkit_ConstantValueTag$param_ptypes$getValue$824c7561d2f47329[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329 = {
	.name=			"getValue",
	.signature=		"()[B",
	.class=			&_jc_soot_tagkit_ConstantValueTag$type,
	.return_type=		&_jc_byte$array$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_ConstantValueTag$param_ptypes$getValue$824c7561d2f47329,
	.signature_hash=	_JC_JLONG(0x824c7561d2f47329),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_ConstantValueTag$vtable, soot_tagkit_ConstantValueTag.getValue$824c7561d2f47329) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_ConstantValueTag$linenum_table$getValue$824c7561d2f47329
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_ConstantValueTag, getValue$824c7561d2f47329);

_jc_byte_array *
_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329(_jc_env *const env, _jc_soot_tagkit_ConstantValueTag$object *this)
{
	struct _jc_soot_tagkit_ConstantValueTag$object *r0;
	_jc_byte_array *r1;

	r0 = this;
	_JC_LINE_NUMBER(41);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_tagkit_ConstantValueTag, bytes);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_ConstantValueTag$methods[] = {
	&_jc_soot_tagkit_ConstantValueTag$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882,
	&_jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$interfaces[] = {
	&_jc_soot_tagkit_Tag$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_110[] = {
	&_jc_soot_tagkit_ConstantValueTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_58,
	[110]=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_110,
	[113]=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_ConstantValueTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/VMClass",	_JC_JLONG(0x2441695b7a69eb12) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_ConstantValueTag$vtype _jc_soot_tagkit_ConstantValueTag$type = {
    .type= {
	.name=			"soot/tagkit/ConstantValueTag",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_tagkit_ConstantValueTag$interfaces) / sizeof(*_jc_soot_tagkit_ConstantValueTag$interfaces),
	.interfaces=		_jc_soot_tagkit_ConstantValueTag$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x927f75e1f2873cee),
		.source_file=		"ConstantValueTag.java",
		.instance_size=		sizeof(_jc_soot_tagkit_ConstantValueTag$refs) + sizeof(_jc_soot_tagkit_ConstantValueTag$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_tagkit_ConstantValueTag$fields) / sizeof(*_jc_soot_tagkit_ConstantValueTag$fields),
		.fields=		_jc_soot_tagkit_ConstantValueTag$fields,
		.num_methods=		sizeof(_jc_soot_tagkit_ConstantValueTag$methods) / sizeof(*_jc_soot_tagkit_ConstantValueTag$methods),
		.methods=		_jc_soot_tagkit_ConstantValueTag$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_ConstantValueTag$class_depends) / sizeof(*_jc_soot_tagkit_ConstantValueTag$class_depends),
		.class_depends=		_jc_soot_tagkit_ConstantValueTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_ConstantValueTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	    .getValue$824c7561d2f47329=
		&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/tagkit/ConstantValueTag.c <==
// public abstract class soot.tagkit.ConstantValueTag

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 238a2c0aafd74314 java_lang_VMClass
// @dep_class 312e45ed214d432f java_lang_VMObject
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_VMClass
// @dep_header java_lang_VMObject
// @dep_header soot_tagkit_ConstantValueTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/VMClass.h"
#include "java/lang/VMObject.h"
#include "soot/tagkit/ConstantValueTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// protected byte[] bytes
static _jc_field _jc_soot_tagkit_ConstantValueTag$field_info$bytes = {
	.name=		"bytes",
	.signature=	"[B",
	.class=		&_jc_soot_tagkit_ConstantValueTag$type,
	.type=		&_jc_byte$array$prim$type,
	.access_flags=	_JC_ACC_PROTECTED,
	.offset=	_JC_OFFSETOF(_jc_soot_tagkit_ConstantValueTag$object, refs[-1].soot_tagkit_ConstantValueTag.bytes),
};

// Fields
static _jc_field *const _jc_soot_tagkit_ConstantValueTag$fields[] = {
	&_jc_soot_tagkit_ConstantValueTag$field_info$bytes
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>()
//

static _jc_linenum _jc_soot_tagkit_ConstantValueTag$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_tagkit_ConstantValueTag$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_tagkit_ConstantValueTag$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_tagkit_ConstantValueTag$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_ConstantValueTag$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_soot_tagkit_ConstantValueTag$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_ConstantValueTag$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_ConstantValueTag, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_tagkit_ConstantValueTag$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_tagkit_ConstantValueTag$object *this)
{
	struct _jc_soot_tagkit_ConstantValueTag$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(33);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getName()
//

static _jc_linenum _jc_soot_tagkit_ConstantValueTag$linenum_table$getName$bec186f2ce7e1882[];

static const unsigned char _jc_soot_tagkit_ConstantValueTag$param_ptypes$getName$bec186f2ce7e1882[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882 = {
	.name=			"getName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_ConstantValueTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_ConstantValueTag$param_ptypes$getName$bec186f2ce7e1882,
	.signature_hash=	_JC_JLONG(0xbec186f2ce7e1882),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_ConstantValueTag$vtable, soot_tagkit_ConstantValueTag.getName$bec186f2ce7e1882) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_ConstantValueTag$linenum_table$getName$bec186f2ce7e1882
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_ConstantValueTag, getName$bec186f2ce7e1882);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882(_jc_env *const env, _jc_soot_tagkit_ConstantValueTag$object *this)
{
	jint i0;
	jint i1;
	jint i3;
	struct _jc_soot_tagkit_ConstantValueTag$object *r0;
	struct _jc_java_lang_Class$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_String$object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = _JC_INVOKE_STATIC(env, java_lang_VMObject, getClass$2be11d215bfbfbfe, 0, r0);
	_JC_EXPLICIT_NULL_CHECK(env, r1);
	r2 = _JC_INVOKE_STATIC(env, java_lang_VMClass, getName$7a04fe8e1a654d36, 0, r1);
	_JC_EXPLICIT_NULL_CHECK(env, r2);
	i3 = _JC_PRIM_FIELD(env, r2, java_lang_String, count);
	i3 = i3 - 1;
	i3 = _JC_INVOKE_NONVIRTUAL(env, java_lang_String, lastIndexOf$f519cb8928895c80, 0, r2, 46, i3);
	_JC_LINE_NUMBER(37);				// 0
	i0 = i3 + 1;
	i1 = _JC_PRIM_FIELD(env, r2, java_lang_String, count);
	r3 = _JC_INVOKE_NONVIRTUAL(env, java_lang_String, substring$df0d95f5ebfea7dc, 0, r2, i0, i1);
	return r3;
}

//
// public byte[] getValue()
//

static _jc_linenum _jc_soot_tagkit_ConstantValueTag$linenum_table$getValue$824c7561d2f47329[];

static const unsigned char _jc_soot_tagkit_ConstantValueTag$param_ptypes$getValue$824c7561d2f47329[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329 = {
	.name=			"getValue",
	.signature=		"()[B",
	.class=			&_jc_soot_tagkit_ConstantValueTag$type,
	.return_type=		&_jc_byte$array$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_ConstantValueTag$param_ptypes$getValue$824c7561d2f47329,
	.signature_hash=	_JC_JLONG(0x824c7561d2f47329),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_ConstantValueTag$vtable, soot_tagkit_ConstantValueTag.getValue$824c7561d2f47329) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_ConstantValueTag$linenum_table$getValue$824c7561d2f47329
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_ConstantValueTag, getValue$824c7561d2f47329);

_jc_byte_array * _JC_JCNI_ATTR
_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329(_jc_env *const env, _jc_soot_tagkit_ConstantValueTag$object *this)
{
	struct _jc_soot_tagkit_ConstantValueTag$object *r0;
	_jc_byte_array *r1;

	r0 = this;
	_JC_LINE_NUMBER(41);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_tagkit_ConstantValueTag, bytes);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_ConstantValueTag$methods[] = {
	&_jc_soot_tagkit_ConstantValueTag$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882,
	&_jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$interfaces[] = {
	&_jc_soot_tagkit_Tag$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_110[] = {
	&_jc_soot_tagkit_ConstantValueTag$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_ConstantValueTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_58,
	[101]=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_101,
	[110]=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_bucket_110
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_ConstantValueTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/VMClass",	_JC_JLONG(0x238a2c0aafd74314) },
	{ "java/lang/VMObject",	_JC_JLONG(0x312e45ed214d432f) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_ConstantValueTag$vtype _jc_soot_tagkit_ConstantValueTag$type = {
    .type= {
	.name=			"soot/tagkit/ConstantValueTag",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_tagkit_ConstantValueTag$interfaces) / sizeof(*_jc_soot_tagkit_ConstantValueTag$interfaces),
	.interfaces=		_jc_soot_tagkit_ConstantValueTag$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x927f75e1f2873cee),
		.source_file=		"ConstantValueTag.java",
		.instance_size=		sizeof(_jc_soot_tagkit_ConstantValueTag$refs) + sizeof(_jc_soot_tagkit_ConstantValueTag$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_soot_tagkit_ConstantValueTag$fields) / sizeof(*_jc_soot_tagkit_ConstantValueTag$fields),
		.fields=		_jc_soot_tagkit_ConstantValueTag$fields,
		.num_methods=		sizeof(_jc_soot_tagkit_ConstantValueTag$methods) / sizeof(*_jc_soot_tagkit_ConstantValueTag$methods),
		.methods=		_jc_soot_tagkit_ConstantValueTag$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_ConstantValueTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_ConstantValueTag$class_depends) / sizeof(*_jc_soot_tagkit_ConstantValueTag$class_depends),
		.class_depends=		_jc_soot_tagkit_ConstantValueTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_ConstantValueTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	    .getValue$824c7561d2f47329=
		&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329,
	},
    }
};
